@@ -32,7 +32,9 @@ extern "C" {
 
 #include <tskit/trees.h>
 
-int tsk_convert_newick(tsk_tree_t *tree, tsk_id_t root, size_t precision,
+#define TSK_NEWICK_LEGACY_MS_LABELS (1 << 0)
+
+int tsk_convert_newick(const tsk_tree_t *tree, tsk_id_t root, unsigned int precision,
     tsk_flags_t options, size_t buffer_size, char *buffer);
 
 #ifdef __cplusplus
